@@ -194,6 +194,9 @@ panel.xyplot <-
         if ("smooth" %in% type)
             panel.loess(x, y, horizontal = horizontal,
                         col = col.line, lty = lty, lwd = lwd, ...)
+        if ("spline" %in% type)
+            panel.spline(x, y, horizontal = horizontal,
+                        col = col.line, lty = lty, lwd = lwd, ...)
         if ("a" %in% type)
             panel.linejoin(x, y, 
                            horizontal = horizontal,
@@ -311,7 +314,8 @@ xyplot.formula <-
                        ylab = ylab,
                        xlab.default = form$right.name,
                        ylab.default = form$left.name,
-                       lattice.options = lattice.options), dots))
+                       lattice.options = lattice.options), dots),
+                quote = TRUE)
 
     dots <- foo$dots # arguments not processed by trellis.skeleton
     foo <- foo$foo
